/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2011, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */

package org.jboss.as.server.deployment;

import java.util.Collections;
import java.util.List;
import java.util.Map;

/**
 * An attachment holding the names of services detected in the deployment unit.
 *
 * @author <a href="mailto:david.lloyd@redhat.com">David M. Lloyd</a>
 */
public final class ServicesAttachment {

    private final Map<String, List<String>> services;

    ServicesAttachment(final Map<String, List<String>> services) {
        this.services = services;
    }

    /**
     * Get the service implementations for a given type name.
     *
     * @param serviceTypeName the type name
     * @return the possibly empty list of services
     */
    public List<String> getServiceImplementations(String serviceTypeName) {
        final List<String> strings = services.get(serviceTypeName);
        return strings == null ? Collections.<String>emptyList() : Collections.unmodifiableList(strings);
    }
}
